@@ -167,16 +167,15 @@ class Admin(callbacks.Plugin):
     def channels(self, irc, msg, args):
         """takes no arguments
 
-        Returns the channels the bot is on.  Must be given in private, in order
-        to protect the secrecy of secret channels.
+        Returns the channels the bot is on.
         """
         L = irc.state.channels.keys()
         if L:
             utils.sortBy(ircutils.toLower, L)
-            irc.reply(format('%L', L))
+            irc.reply(format('%L', L), private=True)
         else:
             irc.reply(_('I\'m not currently in any channels.'))
-    channels = wrap(channels, ['private'])
+    channels = wrap(channels)
 
     def do484(self, irc, msg):
         irc = self.pendingNickChanges.get(irc, None)
@@ -232,34 +231,6 @@ class Admin(callbacks.Plugin):
             irc.reply(irc.nick)
     nick = wrap(nick, [additional('nick'), additional('something')])
 
-    @internationalizeDocstring
-    def part(self, irc, msg, args, channel, reason):
-        """[<channel>] [<reason>]
-
-        Tells the bot to part the list of channels you give it.  <channel> is
-        only necessary if you want the bot to part a channel other than the
-        current channel.  If <reason> is specified, use it as the part
-        message.
-        """
-        if channel is None:
-            if irc.isChannel(msg.args[0]):
-                channel = msg.args[0]
-            else:
-                irc.error(Raise=True)
-        try:
-            network = conf.supybot.networks.get(irc.network)
-            network.channels().remove(channel)
-        except KeyError:
-            pass
-        if channel not in irc.state.channels:
-            irc.error(_('I\'m not in %s.') % channel, Raise=True)
-        irc.queueMsg(ircmsgs.part(channel, reason or msg.nick))
-        if msg.nick in irc.state.channels[channel].users:
-            irc.noReply()
-        else:
-            irc.replySuccess()
-    part = wrap(part, [optional('validChannel'), additional('text')])
-
     class capability(callbacks.Commands):
 
         @internationalizeDocstring
