@@ -344,9 +344,11 @@ class Owner(callbacks.Plugin):
 
         Exits the bot with the QUIT message <text>.  If <text> is not given,
         the default quit message (supybot.plugins.Owner.quitMsg) will be used.
-        If there is no default quitMsg set, your nick will be used.
+        If there is no default quitMsg set, your nick will be used. The standard
+        substitutions ($version, $nick, etc.) are all handled appropriately.
         """
         text = text or self.registryValue('quitMsg') or msg.nick
+        text = ircutils.standardSubstitute(irc, msg, text)
         irc.noReply()
         m = ircmsgs.quit(text)
         world.upkeep()
