@@ -34,7 +34,6 @@ import sys
 import json
 import shutil
 import urllib
-import urllib2
 import tarfile
 from cStringIO import StringIO
 
@@ -200,7 +199,7 @@ class GithubRepository(GitRepository):
         return None
 
 
-repositories = {
+repositories = utils.InsensitivePreservingDict({
                'ProgVal':          GithubRepository(
                                                    'ProgVal',
                                                    'Supybot-plugins'
@@ -242,10 +241,6 @@ repositories = {
                                                    'spidey-supybot-plugins',
                                                    'Plugins',
                                                    ),
-               'Antibody':         GithubRepository(
-                                                   'Antibody',
-                                                   'supybot-plugins',
-                                                   ),
                'doorbot':          GithubRepository(
                                                    'hacklab',
                                                    'doorbot',
@@ -302,10 +297,14 @@ repositories = {
                                                    'SupyPlugins',
                                                    ),
                'Iota':             GithubRepository(
-                                                   'IotaSpencer',
+                                                   'ZeeCrazyAtheist',
                                                    'supyplugins',
                                                    ),
-               }
+               'waratte':          GithubRepository(
+                                                   'waratte',
+                                                   'supybot',
+                                                   ),
+               })
 
 class PluginDownloader(callbacks.Plugin):
     """This plugin allows you to install unofficial plugins from
