@@ -52,6 +52,8 @@ from supybot.i18n import PluginInternationalization, internationalizeDocstring
 _ = PluginInternationalization('RSS')
 
 def get_feedName(irc, msg, args, state):
+    if ircutils.isChannel(args[0]):
+        state.errorInvalid('feed name', args[0], 'must not be channel names.')
     if not registry.isValidRegistryName(args[0]):
         state.errorInvalid('feed name', args[0],
                            'Feed names must not include spaces.')
@@ -61,6 +63,18 @@ addConverter('feedName', get_feedName)
 announced_headlines_filename = \
         conf.supybot.directories.data.dirize('RSS_announced.flat')
 
+def only_one_at_once(f):
+    lock = [False]
+    def newf(*args, **kwargs):
+        if lock[0]:
+            return
+        lock[0] = True
+        try:
+            f(*args, **kwargs)
+        finally:
+            lock[0] = False
+    return newf
+
 class Feed:
     __slots__ = ('url', 'name', 'data', 'last_update', 'entries',
             'etag', 'modified', 'initial',
@@ -127,7 +141,6 @@ def save_announces_db(db, fd):
     json.dump(dict((name, list(entries)) for (name, entries) in db), fd)
 
 
-
 class RSS(callbacks.Plugin):
     """This plugin is useful both for announcing updates to RSS feeds in a
     channel, and for retrieving the headlines of RSS feeds via command.  Use
@@ -228,7 +241,7 @@ class RSS(callbacks.Plugin):
 
     def __call__(self, irc, msg):
         self.__parent.__call__(irc, msg)
-        self.update_feeds()
+        threading.Thread(target=self.update_feeds).start()
 
 
     ##################
@@ -272,6 +285,7 @@ class RSS(callbacks.Plugin):
         if self.is_expired(feed):
             self.update_feed(feed)
 
+    @only_one_at_once
     def update_feeds(self):
         announced_feeds = set()
         for irc in world.ircs:
@@ -413,9 +427,13 @@ class RSS(callbacks.Plugin):
             well as URLs for RSS feeds.  <channel> is only necessary if the
             message isn't sent in the channel itself.
             """
+            plugin = irc.getCallback('RSS')
+            invalid_feeds = [x for x in feeds if not plugin.get_feed(x)]
+            if invalid_feeds:
+                irc.error(format(_('These feeds are unknown: %L'),
+                    invalid_feeds), Raise=True)
             announce = conf.supybot.plugins.RSS.announce
             S = announce.get(channel)()
-            plugin = irc.getCallback('RSS')
             for name in feeds:
                 S.add(name)
             announce.get(channel).setValue(S)
