@@ -171,37 +171,6 @@ class ShrinkUrl(callbacks.PluginRegexp):
     shrinkSnarfer = urlSnarfer(shrinkSnarfer)
     shrinkSnarfer.__doc__ = utils.web._httpUrlRe
 
-    @retry
-    def _getLnUrl(self, url):
-        url = utils.web.urlquote(url)
-        try:
-            return self.db.get('ln', url)
-        except KeyError:
-            text = utils.web.getUrl('http://ln-s.net/home/api.jsp?url=' + url)
-            text = text.decode()
-            (code, text) = text.split(None, 1)
-            text = text.strip()
-            if code == '200':
-                self.db.set('ln', url, text)
-                return text
-            else:
-                raise ShrinkError(text)
-
-    @internationalizeDocstring
-    def ln(self, irc, msg, args, url):
-        """<url>
-
-        Returns an ln-s.net version of <url>.
-        """
-        try:
-            lnurl = self._getLnUrl(url)
-            m = irc.reply(lnurl)
-            if m is not None:
-                m.tag('shrunken')
-        except ShrinkError as e:
-            irc.error(str(e))
-    ln = thread(wrap(ln, ['url']))
-
     @retry
     def _getTinyUrl(self, url):
         try:
@@ -227,69 +196,7 @@ class ShrinkUrl(callbacks.PluginRegexp):
                 m.tag('shrunken')
         except ShrinkError as e:
             irc.errorPossibleBug(str(e))
-    tiny = thread(wrap(tiny, ['url']))
-
-    _xrlApi = 'http://metamark.net/api/rest/simple'
-    @retry
-    def _getXrlUrl(self, url):
-        quotedurl = utils.web.urlquote(url)
-        try:
-            return self.db.get('xrl', quotedurl)
-        except KeyError:
-            data = utils.web.urlencode({'long_url': url})
-            text = utils.web.getUrl(self._xrlApi, data=data).decode()
-            if text.startswith('ERROR:'):
-                raise ShrinkError(text[6:])
-            self.db.set('xrl', quotedurl, text)
-            return text
-
-    @internationalizeDocstring
-    def xrl(self, irc, msg, args, url):
-        """<url>
-
-        Returns an xrl.us version of <url>.
-        """
-        try:
-            xrlurl = self._getXrlUrl(url)
-            m = irc.reply(xrlurl)
-            if m is not None:
-                m.tag('shrunken')
-        except ShrinkError as e:
-            irc.error(str(e))
-    xrl = thread(wrap(xrl, ['url']))
-
-    _gooApi = 'https://www.googleapis.com/urlshortener/v1/url'
-    @retry
-    def _getGooUrl(self, url):
-        try:
-            return self.db.get('goo', url)
-        except KeyError:
-            headers = utils.web.defaultHeaders.copy()
-            headers['content-type'] = 'application/json'
-            data = json.dumps({'longUrl': url})
-            text = utils.web.getUrl(self._gooApi, data=data, headers=headers)
-            if sys.version_info[0] >= 3 and isinstance(text, bytes):
-                text = text.decode()
-            googl = json.loads(text)['id']
-            if googl:
-                self.db.set('goo', url, googl)
-                return googl
-            else:
-                raise ShrinkError(text)
-
-    def goo(self, irc, msg, args, url):
-        """<url>
-
-        Returns an goo.gl version of <url>.
-        """
-        try:
-            goourl = self._getGooUrl(url)
-            m = irc.reply(goourl)
-            if m is not None:
-                m.tag('shrunken')
-        except ShrinkError as e:
-            irc.error(str(e))
-    goo = thread(wrap(goo, ['url']))
+    tiny = thread(wrap(tiny, ['httpUrl']))
 
     _ur1Api = 'http://ur1.ca/'
     _ur1Regexp = re.compile(r'<a href="(?P<url>[^"]+)">')
@@ -319,7 +226,7 @@ class ShrinkUrl(callbacks.PluginRegexp):
                 m.tag('shrunken')
         except ShrinkError as e:
             irc.error(str(e))
-    ur1 = thread(wrap(ur1, ['url']))
+    ur1 = thread(wrap(ur1, ['httpUrl']))
 
     _x0Api = 'http://api.x0.no/?%s'
     @retry
@@ -346,7 +253,7 @@ class ShrinkUrl(callbacks.PluginRegexp):
                 m.tag('shrunken')
         except ShrinkError as e:
             irc.error(str(e))
-    x0 = thread(wrap(x0, ['url']))
+    x0 = thread(wrap(x0, ['httpUrl']))
 
     @retry
     def _getExpandUrl(self, url):
@@ -373,7 +280,7 @@ class ShrinkUrl(callbacks.PluginRegexp):
                 m.tag('shrunken')
         except ShrinkError as e:
             irc.error(str(e))
-    expand = thread(wrap(expand, ['url']))
+    expand = thread(wrap(expand, ['httpUrl']))
 
 Class = ShrinkUrl
 
