@@ -101,6 +101,9 @@ class String(callbacks.Plugin):
         elif sys.version_info[0] >= 3 and isinstance(text, bytes):
             text = text.decode()
 
+        if encoding in ('base64', 'base64_codec'):
+            text = text.replace('\n', '')
+
         # Reply
         irc.reply(text.rstrip('\n'))
     encode = wrap(encode, ['something', 'text'])
@@ -140,7 +143,10 @@ class String(callbacks.Plugin):
         if sys.version_info[0] < 3 and isinstance(text, unicode):
             text = text.encode('utf-8')
         elif sys.version_info[0] >= 3 and isinstance(text, bytes):
-            text = text.decode()
+            try:
+                text = text.decode()
+            except UnicodeDecodeError:
+                pass
 
         # Reply
         irc.reply(text)
