@@ -49,8 +49,6 @@ class WebTestCase(ChannelPluginTestCase):
             self.assertNotError('size http://www.slashdot.org/')
 
         def testTitle(self):
-            self.assertRegexp('title http://www.slashdot.org/',
-                              'News for nerds, stuff that matters')
             # Checks for @title not-working correctly
             self.assertResponse('title '
                 'http://www.catb.org/~esr/jargon/html/F/foo.html',
@@ -65,11 +63,11 @@ class WebTestCase(ChannelPluginTestCase):
             # part of it.
             self.assertRegexp('title http://www.n-e-r-d.com/', 'N.*E.*R.*D')
             # Checks that the parser doesn't hang on invalid tags
-            print()
-            print("If we have not fixed a bug with the parser, the following")
-            print("test will hang the test-suite.")
             self.assertNotError(
                         'title http://www.youtube.com/watch?v=x4BtiqPN4u8')
+            self.assertResponse(
+                    'title http://www.thefreedictionary.com/don%27t',
+                    "don't - definition of don't by The Free Dictionary")
 
         def testTitleSnarfer(self):
             try:
