@@ -41,7 +41,6 @@ import shlex
 import codecs
 import getopt
 import inspect
-import operator
 
 if sys.version_info[0] < 3:
     # cStringIO is buggy with Python 2.6 (
@@ -836,21 +835,24 @@ class NestedCommandsIrcProxy(ReplyIrcProxy):
             else:
                 cb._callCommand(command, self, self.msg, args)
 
-    def reply(self, s, noLengthCheck=False, prefixNick=None,
-              action=None, private=None, notice=None, to=None, msg=None):
+    def reply(self, s, noLengthCheck=False, prefixNick=None, action=None,
+              private=None, notice=None, to=None, msg=None, sendImmediately=False):
         """
         Keyword arguments:
 
-        * `noLengthCheck=False`: True if the length shouldn't be checked
-                                 (used for 'more' handling)
-        * `prefixNick=True`:     False if the nick shouldn't be prefixed to the
-                                 reply.
-        * `action=False`:        True if the reply should be an action.
-        * `private=False`:       True if the reply should be in private.
-        * `notice=False`:        True if the reply should be noticed when the
-                                 bot is configured to do so.
-        * `to=<nick|channel>`:   The nick or channel the reply should go to.
-                                 Defaults to msg.args[0] (or msg.nick if private)
+        * `noLengthCheck=False`:   True if the length shouldn't be checked
+                                   (used for 'more' handling)
+        * `prefixNick=True`:       False if the nick shouldn't be prefixed to the
+                                   reply.
+        * `action=False`:          True if the reply should be an action.
+        * `private=False`:         True if the reply should be in private.
+        * `notice=False`:          True if the reply should be noticed when the
+                                   bot is configured to do so.
+        * `to=<nick|channel>`:     The nick or channel the reply should go to.
+                                   Defaults to msg.args[0] (or msg.nick if private)
+        * `sendImmediately=False`: True if the reply should use sendMsg() which
+                                   bypasses conf.supybot.protocols.irc.throttleTime
+                                   and gets sent before any queued messages
         """
         # These use and or or based on whether or not they default to True or
         # False.  Those that default to True use and; those that default to
@@ -858,6 +860,10 @@ class NestedCommandsIrcProxy(ReplyIrcProxy):
         assert not isinstance(s, ircmsgs.IrcMsg), \
                'Old code alert: there is no longer a "msg" argument to reply.'
         self.repliedTo = True
+        if sendImmediately:
+            sendMsg = self.irc.sendMsg
+        else:
+            sendMsg = self.irc.queueMsg
         if msg is None:
             msg = self.msg
         if prefixNick is not None:
@@ -895,7 +901,7 @@ class NestedCommandsIrcProxy(ReplyIrcProxy):
                               action=self.action,
                               private=self.private,
                               prefixNick=self.prefixNick)
-                    self.irc.queueMsg(m)
+                    sendMsg(m)
                     return m
                 else:
                     s = ircutils.safeArgument(s)
@@ -919,7 +925,13 @@ class NestedCommandsIrcProxy(ReplyIrcProxy):
                         # In case we're truncating, we add 20 to allowedLength,
                         # because our allowedLength is shortened for the
                         # "(XX more messages)" trailer.
-                        s = s[:allowedLength+len(_('(XX more messages)'))]
+                        if sys.version_info[0] >= 3:
+                            appended = _('(XX more messages)').encode()
+                            s = s.encode()[:allowedLength+len(appended)]
+                            s = s.decode('utf8', 'ignore')
+                        else:
+                            appended = _('(XX more messages)')
+                            s = s[:allowedLength+len(appended)]
                         # There's no need for action=self.action here because
                         # action implies noLengthCheck, which has already been
                         # handled.  Let's stick an assert in here just in case.
@@ -928,7 +940,7 @@ class NestedCommandsIrcProxy(ReplyIrcProxy):
                                   notice=self.notice,
                                   private=self.private,
                                   prefixNick=self.prefixNick)
-                        self.irc.queueMsg(m)
+                        sendMsg(m)
                         return m
                     msgs = ircutils.wrap(s, allowedLength,
                             break_long_words=True)
@@ -941,7 +953,7 @@ class NestedCommandsIrcProxy(ReplyIrcProxy):
                                   notice=self.notice,
                                   private=self.private,
                                   prefixNick=self.prefixNick)
-                        self.irc.queueMsg(m)
+                        sendMsg(m)
                         # XXX We should somehow allow these to be returned, but
                         #     until someone complains, we'll be fine :)  We
                         #     can't return from here, though, for obvious
@@ -974,7 +986,7 @@ class NestedCommandsIrcProxy(ReplyIrcProxy):
                                             notice=self.notice,
                                             private=self.private,
                                             prefixNick=self.prefixNick)
-                    self.irc.queueMsg(m)
+                    sendMsg(m)
                     return m
             finally:
                 self._resetReplyAttributes()
@@ -1274,8 +1286,10 @@ class Commands(BasePlugin):
             self.log.debug('Got %s, giving argument error.',
                            utils.exnToString(e))
             help = self.getCommandHelp(command)
-            if help.endswith('command has no help.'):
-                irc.error(_('Invalid arguments for %s.') % method.__name__)
+            if 'command has no help.' in help:
+                # Note: this case will never happen, unless 'checkDoc' is set
+                # to False.
+                irc.error(_('Invalid arguments for %s.') % ' '.join(command))
             else:
                 irc.reply(help)
         except (SyntaxError, Error) as e:
@@ -1344,7 +1358,8 @@ class PluginMixin(BasePlugin, irclib.IrcCallback):
             if ircutils.isChannel(channel):
                 group = group.get(channel)
             else:
-                self.log.debug('registryValue got channel=%r', channel)
+                self.log.debug('%s: registryValue got channel=%r', plugin,
+                               channel)
         if value:
             return group()
         else:
