@@ -344,6 +344,10 @@ def registerNetwork(name, password='', ssl=False, sasl_username='',
     registerGlobalValue(sasl, 'password', registry.String(sasl_password,
         _("""Determines what SASL password will be used on %s.""") \
         % name, private=True))
+    registerGlobalValue(sasl, 'ecdsa_key', registry.String('',
+        _("""Determines what SASL ECDSA key (if any) will be used on %s.
+        The public key must be registered with NickServ for SASL
+        ECDSA-NIST256P-CHALLENGE to work.""") % name, private=False))
     registerGlobalValue(network, 'socksproxy', registry.String('',
         _("""If not empty, determines the hostname of the socks proxy that
         will be used to connect to this network.""")))
@@ -367,7 +371,7 @@ registerGroup(supybot.reply, 'format')
 registerChannelValue(supybot.reply.format, 'url',
     registry.String('<%s>', _("""Determines how urls should be formatted.""")))
 registerChannelValue(supybot.reply.format, 'time',
-    registry.String('%Y-%m-%d %H:%M:%S%z', _("""Determines how timestamps
+    registry.String('%Y-%m-%dT%H:%M:%S%z', _("""Determines how timestamps
     printed for human reading should be formatted. Refer to the Python
     documentation for the time module to see valid formatting characters for
     time formats.""")))
@@ -466,8 +470,7 @@ registerChannelValue(supybot.reply, 'withNotice',
 registerGlobalValue(supybot.reply, 'withNoticeWhenPrivate',
     registry.Boolean(True, _("""Determines whether the bot will reply with a
     notice when it is sending a private message, in order not to open a /query
-    window in clients.  This can be overridden by individual users via the user
-    configuration variable reply.withNoticeWhenPrivate.""")))
+    window in clients.""")))
 
 registerChannelValue(supybot.reply, 'withNickPrefix',
     registry.Boolean(True, _("""Determines whether the bot will always prefix
