@@ -34,11 +34,8 @@ Supybot internationalisation and localisation managment.
 __all__ = ['PluginInternationalization', 'internationalizeDocstring']
 
 import os
-import re
 import sys
-import time
 import weakref
-import threading
 conf = None
 # Don't import conf here ; because conf needs this module
 
@@ -70,7 +67,8 @@ def import_conf():
     conf = __import__('supybot.conf').conf
     conf.registerGlobalValue(conf.supybot, 'language',
         conf.registry.String(currentLocale, """Determines the bot's default
-        language. Valid values are things like en, fr, de, etc."""))
+        language if translations exist. Currently supported are 'de', 'en',
+        'es', 'fi', 'fr' and 'it'."""))
     conf.supybot.language.addCallback(reloadLocalesIfRequired)
 
 def getPluginDir(plugin_name):
