@@ -33,9 +33,15 @@ import time
 import random
 import base64
 
+try:
+    from ecdsa import SigningKey, BadDigestError
+    ecdsa = True
+except ImportError:
+    ecdsa = False
+
 from . import conf, ircdb, ircmsgs, ircutils, log, utils, world
 from .utils.str import rsplit
-from .utils.iter import imap, chain, cycle
+from .utils.iter import chain
 from .utils.structures import queue, smallqueue, RingBuffer
 
 ###
@@ -475,7 +481,7 @@ class IrcState(IrcCommandDispatcher):
                 converter = self._005converters.get(name, lambda x: x)
                 try:
                     self.supported[name] = converter(value)
-                except Exception as e:
+                except Exception:
                     log.exception('Uncaught exception in 005 converter:')
                     log.error('Name: %s, Converter: %s', name, converter)
             else:
@@ -924,6 +930,11 @@ class Irc(IrcCommandDispatcher):
         # TODO Find a better way to fix this
         if hasattr(self.sasl_password, 'decode'):
             self.sasl_password = self.sasl_password.decode('utf-8')
+        self.sasl_ecdsa_key = \
+                conf.supybot.networks.get(self.network).sasl.ecdsa_key()
+        # TODO Find a better way to fix this
+        if hasattr(self.sasl_ecdsa_key, 'decode'):
+            self.sasl_ecdsa_key = self.sasl_ecdsa_key.decode('utf-8')
         self.prefix = '%s!%s@%s' % (self.nick, self.ident, 'unset.domain')
         # The rest.
         self.lastTake = 0
@@ -943,19 +954,20 @@ class Irc(IrcCommandDispatcher):
 
         self.sasl = None
 
-        if (conf.supybot.networks.get(self.network).certfile() or
+        if ecdsa and self.sasl_username and self.sasl_ecdsa_key:
+            self.sasl = 'ecdsa-nist256p-challenge'
+        elif (conf.supybot.networks.get(self.network).certfile() or
                 conf.supybot.protocols.irc.certfile()):
             self.sasl = 'external'
         elif self.sasl_username and self.sasl_password:
             self.sasl = 'plain'
 
+        for cap in ('account-notify', 'extended-join', 'multi-prefix'):
+            self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('REQ', cap)))
+
         if self.sasl:
             self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('REQ', 'sasl')))
-
-        self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('REQ', 'account-notify')))
-        self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('REQ', 'extended-join')))
-
-        if not self.sasl:
+        else:
             self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('END',)))
 
         if self.password:
@@ -980,6 +992,9 @@ class Irc(IrcCommandDispatcher):
 
             if self.sasl == 'external':
                 authstring = '+'
+            elif self.sasl == 'ecdsa-nist256p-challenge':
+                authstring = base64.b64encode(
+                    self.sasl_username.encode('utf-8')).decode('utf-8')
             elif self.sasl == 'plain':
                 authstring = base64.b64encode('\0'.join([
                     self.sasl_username,
@@ -988,6 +1003,17 @@ class Irc(IrcCommandDispatcher):
                 ]).encode('utf-8')).decode('utf-8')
 
             self.queueMsg(ircmsgs.IrcMsg(command='AUTHENTICATE', args=(authstring,)))
+        elif (len(msg.args) == 1 and msg.args[0] != '+' and
+                self.sasl == 'ecdsa-nist256p-challenge'):
+            try:
+                private_key = SigningKey.from_pem(open(self.sasl_ecdsa_key).
+                    read())
+                authstring = base64.b64encode(
+                    private_key.sign(base64.b64decode(msg.args[0].encode()))).decode('utf-8')
+            except (BadDigestError, OSError, ValueError) as e:
+                authstring = "*"
+
+            self.queueMsg(ircmsgs.IrcMsg(command='AUTHENTICATE', args=(authstring,)))
 
     def doCap(self, msg):
         if len(msg.args) == 3:
@@ -1004,14 +1030,20 @@ class Irc(IrcCommandDispatcher):
                     log.warning('%s: Server refused capability %r',
                                 self.network, cap)
 
+                    if cap == 'sasl':
+                        self.queueMsg(ircmsgs.IrcMsg(
+                            command='CAP',
+                            args=('END',)))
+
     def do903(self, msg):
         log.info('%s: SASL authentication successful', self.network)
         self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('END',)))
 
     def do904(self, msg):
-        if (self.sasl == 'external' and self.sasl_username and
+        if (self.sasl != 'plain' and self.sasl_username and
                 self.sasl_password):
-            log.info('%s: SASL EXTERNAL failed, trying PLAIN.', self.network)
+            log.info('%s: SASL %s failed, trying PLAIN.', self.network,
+                self.sasl.upper())
 
             self.sasl = 'plain'
 
