@@ -389,6 +389,8 @@ class IrcTestCase(SupyTestCase):
         m = self.irc.takeMsg()
         self.failUnless(m.command == 'CAP', 'Expected CAP, got %r.' % m)
         m = self.irc.takeMsg()
+        self.failUnless(m.command == 'CAP', 'Expected CAP, got %r.' % m)
+        m = self.irc.takeMsg()
         self.failUnless(m.command == 'USER', 'Expected USER, got %r.' % m)
 
     def testPingResponse(self):
@@ -485,11 +487,14 @@ class IrcCallbackTestCase(SupyTestCase):
             conf.supybot.nick.setValue(nick)
             user = 'user any user'
             conf.supybot.user.setValue(user)
-            expected = [ircmsgs.nick(nick),
-                        ircmsgs.IrcMsg(command='CAP', args=('REQ', 'account-notify')),
-                        ircmsgs.IrcMsg(command='CAP', args=('REQ', 'extended-join')),
-                        ircmsgs.IrcMsg(command='CAP', args=('END',)),
-                        ircmsgs.user('limnoria', user)]
+            expected = [
+                ircmsgs.nick(nick),
+                ircmsgs.IrcMsg(command='CAP', args=('REQ', 'account-notify')),
+                ircmsgs.IrcMsg(command='CAP', args=('REQ', 'extended-join')),
+                ircmsgs.IrcMsg(command='CAP', args=('REQ', 'multi-prefix')),
+                ircmsgs.IrcMsg(command='CAP', args=('END',)),
+                ircmsgs.user('limnoria', user)
+            ]
             irc = irclib.Irc('test')
             msgs = [irc.takeMsg()]
             while msgs[-1] != None:
